"""HuggingFace extractor manifest - Part 2 (SE, multilingual, medical, translation)."""

base_import: str = "wisent.extractors.hf."

EXTRACTORS_PART2: dict[str, str] = {
    # Software Engineering benchmarks (NOT lm-eval)
    "swe_bench_verified": f"{base_import}swe_bench_verified:SWEBenchVerifiedExtractor",
    "swe-bench-verified": f"{base_import}swe_bench_verified:SWEBenchVerifiedExtractor",
    "swebench_verified": f"{base_import}swe_bench_verified:SWEBenchVerifiedExtractor",

    # Scientific Computing benchmarks (NOT lm-eval)
    "scicode": f"{base_import}scicode:SciCodeExtractor",
    "sci_code": f"{base_import}scicode:SciCodeExtractor",

    # Instruction Following benchmarks (NOT lm-eval)
    "alpaca_eval": f"{base_import}alpaca_eval:AlpacaEvalExtractor",
    "alpacaeval": f"{base_import}alpaca_eval:AlpacaEvalExtractor",
    "alpaca_eval_2": f"{base_import}alpaca_eval:AlpacaEvalExtractor",

    # Arena/Chat benchmarks (NOT lm-eval)
    "arena_hard": f"{base_import}arena_hard:ArenaHardExtractor",
    "arena-hard": f"{base_import}arena_hard:ArenaHardExtractor",
    "arenahard": f"{base_import}arena_hard:ArenaHardExtractor",

    # Safety/Refusal benchmarks (NOT lm-eval)
    "sorry_bench": f"{base_import}sorry_bench:SorryBenchExtractor",
    "sorry-bench": f"{base_import}sorry_bench:SorryBenchExtractor",
    "sorrybench": f"{base_import}sorry_bench:SorryBenchExtractor",
    "jailbreakbench": f"{base_import}jailbreakbench:JailbreakBenchExtractor",
    "jailbreak_bench": f"{base_import}jailbreakbench:JailbreakBenchExtractor",
    "jbb": f"{base_import}jailbreakbench:JailbreakBenchExtractor",
    "harmbench": f"{base_import}harmbench:HarmBenchExtractor",
    "harm_bench": f"{base_import}harmbench:HarmBenchExtractor",
    "harm-bench": f"{base_import}harmbench:HarmBenchExtractor",

    # Over-refusal benchmarks (NOT lm-eval)
    "or_bench": f"{base_import}or_bench:ORBenchExtractor",
    "or-bench": f"{base_import}or_bench:ORBenchExtractor",
    "orbench": f"{base_import}or_bench:ORBenchExtractor",
    "or_bench_hard": f"{base_import}or_bench:ORBenchExtractor",
    "or_bench_80k": f"{base_import}or_bench:ORBenchExtractor",

    # Function calling benchmarks (NOT lm-eval)
    "bfcl": f"{base_import}bfcl:BFCLExtractor",
    "berkeley_function_calling": f"{base_import}bfcl:BFCLExtractor",
    "function_calling_leaderboard": f"{base_import}bfcl:BFCLExtractor",

    # Hallucination benchmarks (NOT lm-eval)
    "halueval": f"{base_import}halueval:HaluEvalExtractor",
    "halu_eval": f"{base_import}halueval:HaluEvalExtractor",
    "hallucination_eval": f"{base_import}halueval:HaluEvalExtractor",

    # Agent benchmarks (NOT lm-eval)
    "agentbench": f"{base_import}agentbench:AgentBenchExtractor",
    "agent_bench": f"{base_import}agentbench:AgentBenchExtractor",
    "agentinstruct": f"{base_import}agentbench:AgentBenchExtractor",

    # Math Olympiad benchmarks (NOT lm-eval)
    "olympiadbench": f"{base_import}olympiadbench:OlympiadBenchExtractor",
    "olympiad_bench": f"{base_import}olympiadbench:OlympiadBenchExtractor",
    "imo_answerbench": f"{base_import}olympiadbench:OlympiadBenchExtractor",
    "imo_math": f"{base_import}olympiadbench:OlympiadBenchExtractor",

    # Chinese benchmarks (NOT lm-eval)
    "cluewsc": f"{base_import}cluewsc:CLUEWSCExtractor",
    "cluewsc2020": f"{base_import}cluewsc:CLUEWSCExtractor",
    "clue_wsc": f"{base_import}cluewsc:CLUEWSCExtractor",
    "chinese_simpleqa": f"{base_import}chinese_simpleqa:ChineseSimpleQAExtractor",
    "c_simpleqa": f"{base_import}chinese_simpleqa:ChineseSimpleQAExtractor",
    "csimpleqa": f"{base_import}chinese_simpleqa:ChineseSimpleQAExtractor",

    # Competitive programming benchmarks (NOT lm-eval)
    "codeforces": f"{base_import}codeforces:CodeforcesExtractor",
    "code_forces": f"{base_import}codeforces:CodeforcesExtractor",
    "codeelo": f"{base_import}codeforces:CodeforcesExtractor",

    # Code editing benchmarks (NOT lm-eval)
    "aider_polyglot": f"{base_import}aider_polyglot:AiderPolyglotExtractor",
    "aider-polyglot": f"{base_import}aider_polyglot:AiderPolyglotExtractor",
    "polyglot": f"{base_import}aider_polyglot:AiderPolyglotExtractor",
    "code_exercises": f"{base_import}aider_polyglot:AiderPolyglotExtractor",

    # Agent safety benchmarks (NOT lm-eval)
    "agentharm": f"{base_import}agentharm:AgentHarmExtractor",
    "agent_harm": f"{base_import}agentharm:AgentHarmExtractor",
    "agent-harm": f"{base_import}agentharm:AgentHarmExtractor",

    # Safety refusal benchmarks (NOT lm-eval)
    "donotanswer": f"{base_import}donotanswer:DoNotAnswerExtractor",
    "do_not_answer": f"{base_import}donotanswer:DoNotAnswerExtractor",
    "do-not-answer": f"{base_import}donotanswer:DoNotAnswerExtractor",
    "wildguard": f"{base_import}wildguard:WildGuardExtractor",
    "wildguardmix": f"{base_import}wildguard:WildGuardExtractor",
    "wild_guard": f"{base_import}wildguard:WildGuardExtractor",

    # Hallucination benchmarks (NOT lm-eval)
    "faithbench": f"{base_import}faithbench:FaithBenchExtractor",
    "faith_bench": f"{base_import}faithbench:FaithBenchExtractor",
    "faith-bench": f"{base_import}faithbench:FaithBenchExtractor",

    # Sycophancy benchmarks (NOT lm-eval)
    "sycophancy_eval": f"{base_import}sycophancy_eval:SycophancyEvalExtractor",
    "sycophancy-eval": f"{base_import}sycophancy_eval:SycophancyEvalExtractor",
    "syceval": f"{base_import}sycophancy_eval:SycophancyEvalExtractor",
    "syc_eval": f"{base_import}sycophancy_eval:SycophancyEvalExtractor",

    # Agent task benchmarks (NOT lm-eval)
    "tau_bench": f"{base_import}tau_bench:TauBenchExtractor",
    "tau-bench": f"{base_import}tau_bench:TauBenchExtractor",
    "taubench": f"{base_import}tau_bench:TauBenchExtractor",
    "tau2_bench": f"{base_import}tau_bench:TauBenchExtractor",

    # Agent safety/emulation benchmarks (NOT lm-eval)
    "toolemu": f"{base_import}toolemu:ToolEmuExtractor",
    "tool_emu": f"{base_import}toolemu:ToolEmuExtractor",
    "tool-emu": f"{base_import}toolemu:ToolEmuExtractor",

    # Function calling/API benchmarks (NOT lm-eval)
    "toolbench": f"{base_import}toolbench:ToolBenchExtractor",
    "tool_bench": f"{base_import}toolbench:ToolBenchExtractor",
    "toolllm": f"{base_import}toolbench:ToolBenchExtractor",
    "tool_llm": f"{base_import}toolbench:ToolBenchExtractor",
    "nexus_function_calling": f"{base_import}toolbench:ToolBenchExtractor",

    # Planning benchmarks (NOT lm-eval)
    "travelplanner": f"{base_import}travelplanner:TravelPlannerExtractor",
    "travel_planner": f"{base_import}travelplanner:TravelPlannerExtractor",
    "travel-planner": f"{base_import}travelplanner:TravelPlannerExtractor",

    # Factuality/Grounding benchmarks (NOT lm-eval)
    "facts_grounding": f"{base_import}facts_grounding:FACTSGroundingExtractor",
    "facts-grounding": f"{base_import}facts_grounding:FACTSGroundingExtractor",
    "factsgrounding": f"{base_import}facts_grounding:FACTSGroundingExtractor",

    # Web browsing benchmarks (NOT lm-eval)
    "browsecomp": f"{base_import}agentic_search:BrowseCompExtractor",
    "browse_comp": f"{base_import}agentic_search:BrowseCompExtractor",
    "browse-comp": f"{base_import}agentic_search:BrowseCompExtractor",
    "browsecomp_zh": f"{base_import}agentic_search:BrowseCompExtractor",

    # Selective refusal benchmarks (NOT lm-eval)
    "refusalbench": f"{base_import}refusalbench:RefusalBenchExtractor",
    "refusal_bench": f"{base_import}refusalbench:RefusalBenchExtractor",
    "refusal-bench": f"{base_import}refusalbench:RefusalBenchExtractor",

    # Chinese value alignment benchmarks (NOT lm-eval)
    "flames": f"{base_import}flames:FlamesExtractor",
    "flames_chinese": f"{base_import}flames:FlamesExtractor",

    # Planning/Reasoning benchmarks (NOT lm-eval)
    "planbench": f"{base_import}planbench:PlanBenchExtractor",
    "plan_bench": f"{base_import}planbench:PlanBenchExtractor",
    "planningbench": f"{base_import}planbench:PlanBenchExtractor",

    # SWE-bench variants (NOT lm-eval)
    "swe_verified": f"{base_import}swe_bench:SWEBenchVerifiedExtractor",
    "swe_bench_verified": f"{base_import}swe_bench:SWEBenchVerifiedExtractor",
    "swebench_verified": f"{base_import}swe_bench:SWEBenchVerifiedExtractor",
    "multi_swe_bench": f"{base_import}swe_bench:MultiSWEBenchExtractor",
    "multiswebench": f"{base_import}swe_bench:MultiSWEBenchExtractor",
    "swe_bench_multilingual": f"{base_import}swe_bench:MultiSWEBenchExtractor",

    # LiveCodeBench V6 (NOT lm-eval)
    "livecodebench_v6": f"{base_import}livecodebench_v6:LiveCodeBenchV6Extractor",
    "livecodebench_v5": f"{base_import}livecodebench_v6:LiveCodeBenchV6Extractor",
    "livecodebench_lite": f"{base_import}livecodebench_v6:LiveCodeBenchV6Extractor",

    # Hallucinations Leaderboard (NOT lm-eval)
    "hallucinations_leaderboard": f"{base_import}hallucinations_leaderboard:HallucinationsLeaderboardExtractor",
    "hallucination_leaderboard": f"{base_import}hallucinations_leaderboard:HallucinationsLeaderboardExtractor",
    "hallu_leaderboard": f"{base_import}hallucinations_leaderboard:HallucinationsLeaderboardExtractor",

    # Longform Writing (NOT lm-eval)
    "longform_writing": f"{base_import}longform_writing:LongformWritingExtractor",
    "longform": f"{base_import}longform_writing:LongformWritingExtractor",
    "longform_generation": f"{base_import}longform_writing:LongformWritingExtractor",

    # Agentic Search benchmarks (NOT lm-eval)
    "seal_0": f"{base_import}agentic_search:SealExtractor",
    "seal": f"{base_import}agentic_search:SealExtractor",
    "finsearchcomp": f"{base_import}agentic_search:FinSearchCompExtractor",
    "fin_search_comp": f"{base_import}agentic_search:FinSearchCompExtractor",
    "financial_search": f"{base_import}agentic_search:FinSearchCompExtractor",

    # Coding benchmarks (NOT lm-eval)
    "oj_bench": f"{base_import}coding_benchmarks:OJBenchExtractor",
    "ojbench": f"{base_import}coding_benchmarks:OJBenchExtractor",
    "online_judge_bench": f"{base_import}coding_benchmarks:OJBenchExtractor",
    "terminal_bench": f"{base_import}coding_benchmarks:TerminalBenchExtractor",
    "terminalbench": f"{base_import}coding_benchmarks:TerminalBenchExtractor",
    "terminal": f"{base_import}coding_benchmarks:TerminalBenchExtractor",
    # scicode and sci_code are already defined earlier - use scicode.py extractor

    # Medium priority benchmarks (NOT lm-eval)
    "cnmo_2024": f"{base_import}medium_priority_benchmarks:CNMOExtractor",
    "cnmo": f"{base_import}medium_priority_benchmarks:CNMOExtractor",
    "chinese_math_olympiad": f"{base_import}medium_priority_benchmarks:CNMOExtractor",
    "curate": f"{base_import}medium_priority_benchmarks:CurateExtractor",
    "personalized_alignment": f"{base_import}medium_priority_benchmarks:CurateExtractor",
    "halulens": f"{base_import}medium_priority_benchmarks:HalulensExtractor",
    "hallu_lens": f"{base_import}medium_priority_benchmarks:HalulensExtractor",
    "hallucination_lens": f"{base_import}medium_priority_benchmarks:HalulensExtractor",
    "politicalbias_qa": f"{base_import}medium_priority_benchmarks:PoliticalBiasExtractor",
    "political_bias": f"{base_import}medium_priority_benchmarks:PoliticalBiasExtractor",
    "politicalbias": f"{base_import}medium_priority_benchmarks:PoliticalBiasExtractor",
    "polyglottoxicityprompts": f"{base_import}medium_priority_benchmarks:PolygloToxicityExtractor",
    "polyglot_toxicity": f"{base_import}medium_priority_benchmarks:PolygloToxicityExtractor",
    "multilingual_toxicity": f"{base_import}medium_priority_benchmarks:PolygloToxicityExtractor",
    # Custom TruthfulQA (loads directly from HF)
    "truthfulqa_custom": f"{base_import}truthfulqa_custom:TruthfulQACustomExtractor",

    # Okapi Multilingual benchmarks
    "okapi_mmlu_multilingual": f"{base_import}okapi_multilingual:OkapiMMLUExtractor",
    "okapi_mmlu": f"{base_import}okapi_multilingual:OkapiMMLUExtractor",
    "okapi_hellaswag_multilingual": f"{base_import}okapi_multilingual:OkapiHellaswagExtractor",
    "okapi_hellaswag": f"{base_import}okapi_multilingual:OkapiHellaswagExtractor",
    "okapi_truthfulqa_multilingual": f"{base_import}okapi_multilingual:OkapiTruthfulQAExtractor",
    "okapi_truthfulqa": f"{base_import}okapi_multilingual:OkapiTruthfulQAExtractor",

    # Multilingual benchmarks
    "paws_x": f"{base_import}multilingual_benchmarks:PawsXExtractor",
    "paws-x": f"{base_import}multilingual_benchmarks:PawsXExtractor",
    "mlqa": f"{base_import}multilingual_benchmarks:MLQAExtractor",
    "darija_bench": f"{base_import}multilingual_benchmarks:DarijaBenchExtractor",
    "eus_exams": f"{base_import}multilingual_benchmarks:EusExamsExtractor",
    "lambada_multilingual_stablelm": f"{base_import}multilingual_benchmarks:LambadaMultilingualExtractor",
    "lambada_multilingual": f"{base_import}multilingual_benchmarks:LambadaMultilingualExtractor",

    # Reasoning benchmarks
    "inverse_scaling": f"{base_import}reasoning_benchmarks:InverseScalingExtractor",

    # Medical benchmarks
    "med_concepts_qa": f"{base_import}medical_benchmarks:MedConceptsQAExtractor",

    # Translation benchmarks
    "translation": f"{base_import}translation_benchmarks:TranslationExtractor",
    "wmt14_en_fr": f"{base_import}translation_benchmarks:WMT14Extractor",
    "wmt14_fr_en": f"{base_import}translation_benchmarks:WMT14Extractor",
    "wmt16_de_en": f"{base_import}translation_benchmarks:WMT16Extractor",
    "wmt16_en_de": f"{base_import}translation_benchmarks:WMT16Extractor",
    "wmt2016": f"{base_import}translation_benchmarks:WMT16Extractor",

    # Multimodal benchmarks
    "mmmu": f"{base_import}multimodal_benchmarks:MMMUExtractor",
}



"""Group task handling for populate_tasks."""

import random
from typing import Dict, Any, List, Optional

from wisent.core.utils import get_all_docs_from_task
from wisent.core.constants import MAX_DEPTH, DEFAULT_NUM_SAMPLES, DISPLAY_TOP_N_TINY, DISPLAY_TOP_N_MINI


def find_working_task_from_group(group_dict: Dict, depth: int = 0, max_depth: int = MAX_DEPTH) -> Any:
    """Recursively search through a ConfigurableGroup to find a task with usable documents."""
    if depth > max_depth:
        print(f"   Warning: Maximum recursion depth ({max_depth}) reached, stopping search")
        return None

    items = list(group_dict.items())
    random.shuffle(items)

    for item_name, item in items[:DISPLAY_TOP_N_TINY]:
        indent = "   " + "  " * depth
        print(f"{indent}Checking '{item_name}'...")

        if hasattr(item, 'items') and callable(item.items):
            print(f"{indent}'{item_name}' is a nested group, going deeper...")
            nested_task = find_working_task_from_group(item, depth + 1, max_depth)
            if nested_task:
                print(f"{indent}Found working task in '{item_name}'")
                return nested_task
            else:
                print(f"{indent}No working tasks in '{item_name}', continuing...")
                continue

        try:
            all_docs, split_counts = get_all_docs_from_task(item)
            if all_docs:
                print(f"{indent}Found working task '{item_name}' with {len(all_docs)} documents (splits: {split_counts})")
                return item
            else:
                print(f"{indent}'{item_name}' has no documents")
        except Exception as e:
            print(f"{indent}'{item_name}' failed: {e}")
            continue

    return None


def expand_group_task(task_name: str, get_task_dict) -> List[str]:
    """Expand a group task name into its individual subtasks."""
    try:
        task_dict = get_task_dict([task_name])
        if task_name not in task_dict:
            return [task_name]

        task = task_dict[task_name]

        if hasattr(task, 'items') and callable(task.items):
            subtasks = []
            for subtask_name, subtask in task.items():
                if hasattr(subtask, 'items') and callable(subtask.items):
                    nested = expand_group_task(subtask_name, get_task_dict)
                    subtasks.extend(nested)
                else:
                    subtasks.append(subtask_name)
            return subtasks
        else:
            return [task_name]
    except Exception as e:
        print(f"   Warning: Could not expand '{task_name}': {e}")
        return [task_name]


def get_samples_from_group_task(group_name: str, subtasks: List[str], num_samples: int = DEFAULT_NUM_SAMPLES) -> Dict[str, Any]:
    """Get samples from a group task by sampling from its subtasks."""
    from lm_eval import evaluator

    print(f"Getting samples from group task '{group_name}' with {len(subtasks)} subtasks...")

    all_samples = []
    samples_per_task = max(1, num_samples // len(subtasks))

    for i, subtask in enumerate(subtasks[:num_samples]):
        try:
            print(f"   Getting samples from subtask {i+1}/{min(len(subtasks), num_samples)}: '{subtask}'...")

            task_dict = evaluator.get_task_dict([subtask])
            if subtask not in task_dict:
                print(f"   Subtask '{subtask}' not found, skipping...")
                continue

            task = task_dict[subtask]
            all_docs, split_counts = get_all_docs_from_task(task)

            if not all_docs:
                print(f"   No documents found for subtask '{subtask}', skipping...")
                continue

            sample_docs = all_docs[:samples_per_task] if len(all_docs) >= samples_per_task else all_docs

            for doc in sample_docs:
                sample = {"sample_id": len(all_samples) + 1, "subtask": subtask}
                sample["question"] = _extract_question(task, doc)
                sample["correct_answer"] = _extract_answer(task, doc)
                sample["choices"], sample["format"], sample["correct_choice_index"] = _extract_choices(doc)
                all_samples.append(sample)

                if len(all_samples) >= num_samples:
                    break

        except Exception as e:
            print(f"   Error processing subtask '{subtask}': {e}")
            continue

        if len(all_samples) >= num_samples:
            break

    if not all_samples:
        return {"task_name": group_name, "error": f"No samples could be retrieved from any subtasks of {group_name}", "samples": []}

    print(f"Successfully retrieved {len(all_samples)} samples from {group_name} group task")

    subtask_names = list(set([sample["subtask"] for sample in all_samples]))
    return {
        "task_name": group_name,
        "description": f"Group task '{group_name}' containing subtasks: {', '.join(subtask_names)}",
        "samples": all_samples[:num_samples],
        "num_subtasks": len(subtasks),
        "sampled_subtasks": subtask_names
    }


def process_group_task(group_name: str, sub_tasks: List[str], get_task_dict) -> Dict[str, Any]:
    """Process a group task and extract information from its subtasks."""
    from .sample_extraction import get_evaluation_method, get_category

    print(f"\nProcessing group task: {group_name} with {len(sub_tasks)} subtasks")

    result = {"name": group_name, "is_group": True, "subtasks": sub_tasks, "num_subtasks": len(sub_tasks)}

    try:
        task_dict = get_task_dict([sub_tasks[0]] if sub_tasks else [group_name])
        first_subtask_name = sub_tasks[0] if sub_tasks else group_name

        if first_subtask_name in task_dict:
            task = task_dict[first_subtask_name]
            result["evaluation_method"] = get_evaluation_method(task)
            result["category"] = get_category(task)
            result["description"] = f"Group task containing: {', '.join(sub_tasks[:DISPLAY_TOP_N_MINI])}" + ("..." if len(sub_tasks) > DISPLAY_TOP_N_MINI else "")
        else:
            result["evaluation_method"] = "unknown"
            result["category"] = "unknown"
            result["description"] = f"Group task with {len(sub_tasks)} subtasks"
    except Exception as e:
        print(f"   Error processing group: {e}")
        result["error"] = str(e)

    return result


def _extract_question(task, doc) -> str:
    """Extract question from document."""
    try:
        if hasattr(task, 'doc_to_text'):
            return str(task.doc_to_text(doc))
        for key in ['question', 'text', 'prompt']:
            if key in doc:
                return str(doc[key])
        return "Question format not recognized"
    except Exception as e:
        return f"Error extracting question: {e}"


def _extract_answer(task, doc) -> str:
    """Extract answer from document."""
    try:
        if hasattr(task, 'doc_to_target'):
            return str(task.doc_to_target(doc))
        for key in ['answer', 'target']:
            if key in doc:
                return str(doc[key])
        return "Answer format not recognized"
    except Exception as e:
        return f"Error extracting answer: {e}"


def _extract_choices(doc) -> tuple:
    """Extract choices from document."""
    try:
        if 'choices' in doc and isinstance(doc['choices'], list):
            choices = [str(choice) for choice in doc['choices']]
            gold = doc.get('gold', doc.get('label', None))
            if isinstance(gold, list) and len(gold) > 0:
                idx = gold[0]
            elif isinstance(gold, int):
                idx = gold
            else:
                idx = None
            return choices, "multiple_choice", idx
        return [], "open_ended", None
    except Exception:
        return [], "unknown", None



"""TurkishMMLU group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.extractors.lm_eval."

# NO PARENT TASK MAPPING - each subtask mapped individually based on output_type

TURKISHMMLU_TASKS = {
    # Multiple_choice subtasks → turkishmmlu_mc.py (evaluator_name = "log_likelihoods")
    "turkishmmlu_biology": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_chemistry": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_geography": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_history": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_mathematics": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_philosophy": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_physics": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_religion_and_ethics": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    "turkishmmlu_turkish_language_and_literature": f"{BASE_IMPORT}turkishmmlu_mc:TurkishmmluMultipleChoiceExtractor",
    # Generate_until (CoT) subtasks → turkishmmlu_cot.py (evaluator_name = "generation")
    "turkishmmlu_cot_biology": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_chemistry": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_geography": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_history": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_mathematics": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_philosophy": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_physics": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_religion_and_ethics": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
    "turkishmmlu_cot_turkish_language_and_literature": f"{BASE_IMPORT}turkishmmlu_cot:TurkishmmluCotExtractor",
}
